package com.muyu.marketing.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.marketing.domain.model.ActivityTeamInfoAddModel;
import com.muyu.marketing.domain.model.ActivityTeamInfoModel;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuAddModel;
import com.muyu.marketing.domain.model.ActivityTeamProductSkuModel;
import lombok.*;
import lombok.experimental.SuperBuilder;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName(value = "activity_team_info", autoResultMap = true)
public class ActivityTeamInfo extends BaseEntity {

  /**
   * 主键
   */
  @TableId(value = "id", type = IdType.AUTO)
  private Long id;
  /**
   * 拼团名称
   */
  private String name;
  /**
   * 商品ID
   */
  private long productId;
  /**
   * 商品活动图
   */
  private String productImage;
  /**
   * 活动简介
   */
  private String introduction;
  /**
   * 单位
   */
  private String unit;
  /**
   * 轮播图
   */
  private String imageList;
  /**
   * 活动结束时间
   */
  @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private Date endTime;
  /**
   * 活动排序
   */
  private Long sort;
  /**
   * 活动详情
   */
  private String content;
  /**
   * 活动状态
   */
  private String status;
  /**
   * 策略类型
   */
  private String strategyType;
  /**
   * 策略ID
   */
  private Long strategyId;
  /**
   * 首页
   */


  /**
   * 公共添加模型，转换成添加对象
   * @param activityTeamInfoAddModel 添加模型
   * @return 添加对象
   */
  public static ActivityTeamInfo addModelBuild(ActivityTeamInfoAddModel activityTeamInfoAddModel){
    return ActivityTeamInfo.builder()
            .name(activityTeamInfoAddModel.getName())
            .productId(activityTeamInfoAddModel.getProductId())
            .productImage(activityTeamInfoAddModel.getProductImage())
            .introduction(activityTeamInfoAddModel.getIntroduction())
            .unit(activityTeamInfoAddModel.getUnit())
            .imageList(activityTeamInfoAddModel.getImageList())
            .endTime(activityTeamInfoAddModel.getEndTime())
            .sort(activityTeamInfoAddModel.getSort())
            .content(activityTeamInfoAddModel.getContent())
            .status(activityTeamInfoAddModel.getStatus())
            .strategyType(activityTeamInfoAddModel.getStrategyType())
            .strategyId(activityTeamInfoAddModel.getStrategyId())
            .build();
  }

  public static ActivityTeamInfo addTeamInfoModelBuild(ActivityTeamInfoModel activityTeamInfoModel) {
    return ActivityTeamInfo.builder()
            .name(activityTeamInfoModel.getName())
            .productId(activityTeamInfoModel.getProductId())
            .productImage(activityTeamInfoModel.getProductImage())
            .introduction(activityTeamInfoModel.getIntroduction())
            .unit(activityTeamInfoModel.getUnit())
            .imageList(activityTeamInfoModel.getImageList())
            .endTime(activityTeamInfoModel.getEndTime())
            .sort(activityTeamInfoModel.getSort())
            .content(activityTeamInfoModel.getContent())
            .status(activityTeamInfoModel.getStatus())
            .strategyType(activityTeamInfoModel.getStrategyType())
            .strategyId(activityTeamInfoModel.getStrategyId())
            .build();
  }
}
