package com.muyu.marketing.team.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.marketing.domain.ActivityTeamProductSkuInfo;
import com.muyu.marketing.domain.TeamStrategyExemptionHundred;
import com.muyu.marketing.domain.model.*;

import java.util.List;

public interface ActivityTeamProductSkuInfoService extends IService<ActivityTeamProductSkuInfo> {

    public default List<ActivityTeamProductSkuInfo> getActivityTeamProductSkuInfoByTeamId(Long teamId){
        LambdaQueryWrapper<ActivityTeamProductSkuInfo> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(ActivityTeamProductSkuInfo::getTeamId, teamId);
        return this.list(lambdaQueryWrapper);
    }


    /**
     * 通过团购活动ID获取团购中最优惠的价格
     * @param teamId 团购ID
     * @return 优惠价格
     */
    public TeamProductDiscountPriceModel getDiscountPrice(Long teamId);


    /**
     * 通过活动ID获取 剩余库存
     * @param teamId 活动ID
     * @return 库存
     */
    public TeamProductStockModel getStock(Long teamId);


    /**
     * 添加团购商品SKU
     * @param activityTeamProductSkuAddModelList 团购商品SKU添加模型集合
     */
    public void batchSave(List<ActivityTeamProductSkuAddModel> activityTeamProductSkuAddModelList);

    /**
     * 通过活动Id查询规格集合数据
     */
    public List<ActivityTeamProductSkuModel> findById(Long id);

    /**
     * 根据 业务模型 对团购商品修改
     */
    public boolean update(ActivityTeamProductSkuModel activityTeamProductSkuModel);


    /**
     * 根据 业务模型 对商品批量修改
     */
    public boolean bathUpdate(List<ActivityTeamProductSkuModel> activityTeamProductSkuModels);

    /**
     * 根据业务模型 对商品批量删除
     */
    public void bathDelete(List<Long> id);

}
